summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/aim/aimaccount.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/aim/aimaccount.cpp')
-rw-r--r--kopete/protocols/oscar/aim/aimaccount.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/kopete/protocols/oscar/aim/aimaccount.cpp b/kopete/protocols/oscar/aim/aimaccount.cpp
index cc890add..33a4b365 100644
--- a/kopete/protocols/oscar/aim/aimaccount.cpp
+++ b/kopete/protocols/oscar/aim/aimaccount.cpp
@@ -200,13 +200,13 @@ void AIMMyselfContact::sendMessage( Kopete::Message& message, Kopete::ChatSessio
}
-AIMAccount::AIMAccount(Kopete::Protocol *tqparent, TQString accountID, const char *name)
- : OscarAccount(tqparent, accountID, name, false)
+AIMAccount::AIMAccount(Kopete::Protocol *parent, TQString accountID, const char *name)
+ : OscarAccount(parent, accountID, name, false)
{
kdDebug(14152) << k_funcinfo << accountID << ": Called."<< endl;
AIMMyselfContact* mc = new AIMMyselfContact( this );
setMyself( mc );
- myself()->setOnlineStatus( static_cast<AIMProtocol*>( tqparent )->statusOffline );
+ myself()->setOnlineStatus( static_cast<AIMProtocol*>( parent )->statusOffline );
TQString profile = configGroup()->readEntry( "Profile",
i18n( "Visit the Kopete website at <a href=\"http://kopete.kde.org\">http://kopete.kde.org</a>") );
mc->setOwnProfile( profile );
@@ -597,13 +597,13 @@ void AIMAccount::disconnected( DisconnectReason reason )
void AIMAccount::messageReceived( const Oscar::Message& message )
{
kdDebug(14152) << k_funcinfo << " Got a message, calling OscarAccount::messageReceived" << endl;
// Want to call the tqparent to do everything else
if ( message.type() != 0x0003 )
{
OscarAccount::messageReceived(message);
// Check to see if our status is away, and send an away message
// Might be duplicate code from the tqparent class to get some needed information
// Perhaps a refactoring is needed.
kdDebug(14152) << k_funcinfo << "Checking to see if I'm online.." << endl;
if( myself()->onlinetqStatus().status() == Kopete::OnlineStatus::Away )
@@ -597,13 +597,13 @@ void AIMAccount::disconnected( DisconnectReason reason )
{
kdDebug(14152) << k_funcinfo << " Got a message, calling OscarAccount::messageReceived" << endl;
- // Want to call the tqparent to do everything else
+ // Want to call the parent to do everything else
if ( message.type() != 0x0003 )
{
@@ -597,13 +597,13 @@ void AIMAccount::disconnected( DisconnectReason reason )
OscarAccount::messageReceived(message);
// Check to see if our status is away, and send an away message
- // Might be duplicate code from the tqparent class to get some needed information
+ // Might be duplicate code from the parent class to get some needed information
// Perhaps a refactoring is needed.
kdDebug(14152) << k_funcinfo << "Checking to see if I'm online.." << endl;